#---------------------------------------------------
# Reading TXT files
#---------------------------------------------------


targets <- readTargets("target.txt")

#target.txt has two columns with headers "FileName" and "Condition"


x <- read.maimages(targets, path="/path/to/files/", source="agilent",green.only=TRUE)
y <- backgroundCorrect(x, method="normexp",offset=16)
y <- normalizeBetweenArrays(y, method="quantile")

#---------------------------------------------------
# Filtering data
#---------------------------------------------------

neg95 <- apply(y$E[y$genes$ControlType==-1,],2,function(x) quantile(x,p=0.95))
cutoff <- matrix(1.15*neg95,nrow(y),ncol(y),byrow=TRUE)
isexpr <- rowSums (y$E > cutoff)>= 4
y0 <- y[y$genes$ControlType==0 & isexpr,]
write.table(y0, file="filtered_data.txt")
y0.ave <- avereps(y0, ID=y0$genes$ProbeName)

#---------------------------------------------------
#Build design matrix for linear modeling function
#---------------------------------------------------

f <- factor(targets$Condition, levels=unique(targets$Condition))
design <- model.matrix(~0 + f)
colnames(design)<- levels(f)

#---------------------------------------------------
#Apply intensity values to lmFit
#---------------------------------------------------

fit <- lmFit(y0.ave, design)

#---------------------------------------------------
#Creating a contrast matrix
#---------------------------------------------------

contrast.matrix <- makeContrasts("ConditionX-ConditionY",levels=design)
fit2 <- contrasts.fit(fit, contrast.matrix)
fit2 <- eBayes(fit2)
write.csv(fit2, file="coefficients.csv")

#coefficients are used as nodeweights in the construction of 32xNet
